@@ -1,7 +1,7 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
  *
- * Copyright (C) 2000-2007 by Alfons Hoogervorst & The Claws Mail Team.
+ * Copyright (C) 2000-2009 by Alfons Hoogervorst & The Claws Mail Team.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -40,6 +40,8 @@
 #include "utils.h"
 #include "prefs_common.h"
 #include "claws.h"
+#include "hooks.h"
+#include "gtkutils.h"
 #include <pthread.h>
 
 /*!
@@ -69,18 +71,7 @@ enum {
  * addresses a little more (e.g. break up alfons@proteus.demon.nl into
  * something like alfons, proteus, demon, nl; and then completing on
  * any of those words).
- */ 
-	
-/**
- * address_entry - structure which refers to the original address entry in the
- * address book .
  */
-typedef struct
-{
-	gchar *name;
-	gchar *address;
-	GList *grp_emails;
-} address_entry;
 
 /**
  * completion_entry - structure used to complete addresses, with a reference
@@ -160,7 +151,7 @@ static gboolean addr_compl_defer_select_destruct(CompletionWindow *window);
  */
 static gchar *completion_func(gpointer data)
 {
-	g_return_val_if_fail(data != NULL, NULL);
+	cm_return_val_if_fail(data != NULL, NULL);
 
 	return ((completion_entry *)data)->string;
 } 
@@ -171,7 +162,7 @@ static gchar *completion_func(gpointer data)
 static void init_all(void)
 {
 	g_completion = g_completion_new(completion_func);
-	g_return_if_fail(g_completion != NULL);
+	cm_return_if_fail(g_completion != NULL);
 }
 
 static void free_all_addresses(void)
@@ -230,7 +221,7 @@ static void free_all(void)
  * \param str Index string value.
  * \param ae  Entry containing address data.
  */
-static void add_address1(const char *str, address_entry *ae)
+void addr_compl_add_address1(const char *str, address_entry *ae)
 {
 	completion_entry *ce1;
 	ce1 = g_new0(completion_entry, 1),
@@ -267,22 +258,22 @@ static gint add_address(const gchar *name, const gchar *address,
 
 	ae = g_new0(address_entry, 1);
 
-	g_return_val_if_fail(ae != NULL, -1);
+	cm_return_val_if_fail(ae != NULL, -1);
 
 	ae->name    = g_strdup(name);
-	ae->address = g_strdup(address);		
+	ae->address = g_strdup(address);
 	ae->grp_emails = grp_emails;
 	g_address_list = g_list_prepend(g_address_list, ae);
 
-	add_address1(name, ae);
+	addr_compl_add_address1(name, ae);
 	if (address != NULL && *address != '\0')
-		add_address1(address, ae);
-	
+		addr_compl_add_address1(address, ae);
+
 	if (nick != NULL && *nick != '\0')
-		add_address1(nick, ae);
-	
+		addr_compl_add_address1(nick, ae);
+
 	if ( alias != NULL && *alias != '\0') {
-		add_address1(alias, ae);
+		addr_compl_add_address1(alias, ae);
 	}
 
 	return 0;
@@ -296,13 +287,17 @@ static void read_address_book(gchar *folderpath) {
 	free_completion_list();
 
 	addrindex_load_completion( add_address, folderpath );
+
+	/* plugins may hook in here to modify/extend the completion list */
+	hooks_invoke(ADDDRESS_COMPLETION_BUILD_ADDRESS_LIST_HOOKLIST, &g_address_list);
+
 	g_address_list = g_list_reverse(g_address_list);
 	g_completion_list = g_list_reverse(g_completion_list);
 	/* merge the completion entry list into g_completion */
 	if (g_completion_list) {
 		g_completion_add_items(g_completion, g_completion_list);
 		if (debug_get_mode())
-			debug_print("read %d items in %s\n", 
+			debug_print("read %d items in %s\n",
 				g_list_length(g_completion_list),
 				folderpath?folderpath:"(null)");
 	}
@@ -499,7 +494,7 @@ guint complete_address(const gchar *str)
 	guint  cpl = 0;
 	completion_entry *ce = NULL;
 
-	g_return_val_if_fail(str != NULL, 0);
+	cm_return_val_if_fail(str != NULL, 0);
 
 	/* g_completion is case sensitive */
 	d = g_utf8_strdown(str, -1);
@@ -549,7 +544,7 @@ guint complete_matches_found(const gchar *str)
 	GList *result = NULL;
 	gchar *d = NULL;
 
-	g_return_val_if_fail(str != NULL, 0);
+	cm_return_val_if_fail(str != NULL, 0);
 
 	/* g_completion is case sensitive */
 	d = g_utf8_strdown(str, -1);
@@ -815,7 +810,7 @@ static void completion_window_advance_selection(GtkTreeView *list_view, gboolean
 	GtkTreeIter iter;
 	GtkTreeModel *model;
 
-	g_return_if_fail(list_view != NULL);
+	cm_return_if_fail(list_view != NULL);
 
 	selection = gtk_tree_view_get_selection(list_view);
 	if (!gtk_tree_selection_get_selected(selection, &model, &iter))
@@ -1081,8 +1076,8 @@ static void completion_window_apply_selection(GtkTreeView *list_view,
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	gboolean is_group = FALSE;
-	g_return_if_fail(list_view != NULL);
-	g_return_if_fail(entry != NULL);
+	cm_return_if_fail(list_view != NULL);
+	cm_return_if_fail(entry != NULL);
 	GList *grp_emails = NULL;
 
 	selection = gtk_tree_view_get_selection(list_view);
@@ -1140,8 +1135,8 @@ void address_completion_start(GtkWidget *mainwindow)
  */
 void address_completion_register_entry(GtkEntry *entry, gboolean allow_commas)
 {
-	g_return_if_fail(entry != NULL);
-	g_return_if_fail(GTK_IS_ENTRY(entry));
+	cm_return_if_fail(entry != NULL);
+	cm_return_if_fail(GTK_IS_ENTRY(entry));
 
 	/* add hooked property */
 	g_object_set_data(G_OBJECT(entry), ENTRY_DATA_TAB_HOOK, entry);
@@ -1164,12 +1159,12 @@ void address_completion_unregister_entry(GtkEntry *entry)
 {
 	GtkObject *entry_obj;
 
-	g_return_if_fail(entry != NULL);
-	g_return_if_fail(GTK_IS_ENTRY(entry));
+	cm_return_if_fail(entry != NULL);
+	cm_return_if_fail(GTK_IS_ENTRY(entry));
 
 	entry_obj = g_object_get_data(G_OBJECT(entry), ENTRY_DATA_TAB_HOOK);
-	g_return_if_fail(entry_obj);
-	g_return_if_fail(G_OBJECT(entry_obj) == G_OBJECT(entry));
+	cm_return_if_fail(entry_obj);
+	cm_return_if_fail(G_OBJECT(entry_obj) == G_OBJECT(entry));
 
 	/* has the hooked property? */
 	g_object_set_data(G_OBJECT(entry), ENTRY_DATA_TAB_HOOK, NULL);
@@ -1264,9 +1259,9 @@ static gboolean address_completion_complete_address_in_entry(GtkEntry *entry,
 	gint ncount, cursor_pos;
 	gchar *searchTerm, *new = NULL;
 
-	g_return_val_if_fail(entry != NULL, FALSE);
+	cm_return_val_if_fail(entry != NULL, FALSE);
 
-	if (!GTK_WIDGET_HAS_FOCUS(entry)) return FALSE;
+	if (!gtkut_widget_has_focus(GTK_WIDGET(entry))) return FALSE;
 
 	/* get an address component from the cursor */
 	searchTerm = get_address_from_edit( entry, &cursor_pos );
@@ -1399,10 +1394,10 @@ static gboolean completion_window_button_press(GtkWidget *widget,
 	gint cursor_pos;
 	gboolean restore = TRUE;
 
-	g_return_val_if_fail(compWin != NULL, FALSE);
+	cm_return_val_if_fail(compWin != NULL, FALSE);
 
 	entry = compWin->entry;
-	g_return_val_if_fail(entry != NULL, FALSE);
+	cm_return_val_if_fail(entry != NULL, FALSE);
 
 	/* Test where mouse was clicked */
 	event_widget = gtk_get_event_widget((GdkEvent *)event);
@@ -1447,11 +1442,11 @@ static gboolean completion_window_key_press(GtkWidget *widget,
 	gint cursor_pos;
 	GtkWidget *list_view;
 	GtkWidget *parent;
-	g_return_val_if_fail(compWin != NULL, FALSE);
+	cm_return_val_if_fail(compWin != NULL, FALSE);
 
 	entry = compWin->entry;
 	list_view = compWin->list_view;
-	g_return_val_if_fail(entry != NULL, FALSE);
+	cm_return_val_if_fail(entry != NULL, FALSE);
 
 	/* allow keyboard navigation in the alternatives tree view */
 	if (event->keyval == GDK_Up || event->keyval == GDK_Down ||
@@ -1681,11 +1676,11 @@ static gboolean addr_compl_selected(GtkTreeSelection *selector,
 	 * not using a time out would result in a crash. if this doesn't work
 	 * safely, maybe we should set variables when receiving button presses
 	 * in the tree view. */
-	if (!window->destroying) {	 
-		window->destroying = TRUE;	 
+	if (!window->destroying) {
+		window->destroying = TRUE;
 		g_idle_add((GSourceFunc) addr_compl_defer_select_destruct, data);
-	}		
-	
+	}
+
 	return TRUE;
 }
 
