@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Match Grun and the Claws Mail team
+ * Copyright (C) 2001-2009 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,10 +62,8 @@ static struct _AddressBookFolderSel_dlg {
 	FolderInfo *fiSelected;
 } addressbook_foldersel_dlg;
 
-static GdkPixmap *folderXpm;
-static GdkBitmap *folderXpmMask;
-static GdkPixmap *bookXpm;
-static GdkBitmap *bookXpmMask;
+static GdkPixbuf *folderXpm;
+static GdkPixbuf *bookXpm;
 
 static gboolean addressbook_foldersel_cancelled;
 
@@ -135,7 +133,7 @@ static gboolean addressbook_foldersel_tree_button( GtkCMCTree *ctree, GdkEventBu
 static void addressbook_foldersel_size_allocate_cb(GtkWidget *widget,
 					 GtkAllocation *allocation)
 {
-	g_return_if_fail(allocation != NULL);
+	cm_return_if_fail(allocation != NULL);
 
 	prefs_common.addressbook_folderselwin_width = allocation->width;
 	prefs_common.addressbook_folderselwin_height = allocation->height;
@@ -158,7 +156,6 @@ static void addressbook_foldersel_create( void )
 	gtk_container_set_border_width( GTK_CONTAINER(window), 0 );
 	gtk_window_set_title( GTK_WINDOW(window), _("Select Address Book Folder") );
 	gtk_window_set_position( GTK_WINDOW(window), GTK_WIN_POS_MOUSE );
-	gtk_window_set_modal( GTK_WINDOW(window), TRUE );
 	g_signal_connect( G_OBJECT(window), "delete_event",
 			  G_CALLBACK(addressbook_foldersel_delete_event), NULL );
 	g_signal_connect( G_OBJECT(window), "key_press_event",
@@ -236,9 +233,9 @@ static void addressbook_foldersel_create( void )
 
 	gtk_widget_show_all( window );
 
-	stock_pixmap_gdk( window, STOCK_PIXMAP_BOOK, &bookXpm, &bookXpmMask );
-	stock_pixmap_gdk( window, STOCK_PIXMAP_DIR_OPEN,
-			  &folderXpm, &folderXpmMask );
+	stock_pixbuf_gdk( window, STOCK_PIXMAP_BOOK, &bookXpm);
+	stock_pixbuf_gdk( window, STOCK_PIXMAP_DIR_OPEN,
+			  &folderXpm);
 }
 
 static void addressbook_foldersel_load_folder( GtkCMCTreeNode *parentNode, ItemFolder *parentFolder,
@@ -260,7 +257,7 @@ static void addressbook_foldersel_load_folder( GtkCMCTreeNode *parentNode, ItemF
 
 		name = &fName;
 		node = gtk_cmctree_insert_node( tree, parentNode, NULL, name, FOLDER_SPACING,
-				folderXpm, folderXpmMask, folderXpm, folderXpmMask,
+				folderXpm, folderXpm,
 				FALSE, TRUE );
 
 		/* match folder name, match pointer will be set to NULL if next recursive call
@@ -330,7 +327,7 @@ static void addressbook_foldersel_load_data( AddressIndex *addrIndex,
 				name = &dsName;
 				node = gtk_cmctree_insert_node( tree, NULL, NULL,
 						name, FOLDER_SPACING, bookXpm,
-						bookXpmMask, bookXpm, bookXpmMask,
+						bookXpm,
 						FALSE, TRUE );
 				g_free( dsName );
 
@@ -384,7 +381,8 @@ gboolean addressbook_foldersel_selection( AddressIndex *addrIndex,
 	gtk_widget_grab_focus(addressbook_foldersel_dlg.ok_btn);
 	gtk_widget_show(addressbook_foldersel_dlg.window);
 	manage_window_set_transient(GTK_WINDOW(addressbook_foldersel_dlg.window));
-
+	gtk_window_set_modal(GTK_WINDOW(addressbook_foldersel_dlg.window), TRUE);
+	
 	addressbook_foldersel_dlg.fiSelected = NULL;
 
 	/* split the folder path we've received, we'll try to match this path, subpath by
@@ -416,7 +414,7 @@ gboolean addressbook_foldersel_selection( AddressIndex *addrIndex,
 
 	gtk_main();
 	gtk_widget_hide( addressbook_foldersel_dlg.window );
-
+	gtk_window_set_modal(GTK_WINDOW(addressbook_foldersel_dlg.window), FALSE);
 	if ( ! addressbook_foldersel_cancelled ) {
 
 		*book = NULL;
