@@ -1028,6 +1028,7 @@ static const struct {
 	{C_EUC_KR,		CS_EUC_KR},
 	{C_ISO_2022_CN,		CS_ISO_2022_CN},
 	{C_EUC_CN,		CS_EUC_CN},
+	{C_GB18030,		CS_GB18030},
 	{C_GB2312,		CS_GB2312},
 	{C_GBK,			CS_GBK},
 	{C_EUC_TW,		CS_EUC_TW},
@@ -1057,9 +1058,10 @@ static const struct {
 #endif
 	{"ko_KR.EUC-KR"	, C_EUC_KR	, C_EUC_KR},
 	{"ko_KR"	, C_EUC_KR	, C_EUC_KR},
+	{"zh_CN.GB18030"	, C_GB18030	, C_GB18030},
 	{"zh_CN.GB2312"	, C_GB2312	, C_GB2312},
 	{"zh_CN.GBK"	, C_GBK		, C_GBK},
-	{"zh_CN"	, C_GB2312	, C_GB2312},
+	{"zh_CN"	, C_GB18030	, C_GB18030},
 	{"zh_HK"	, C_BIG5_HKSCS	, C_BIG5_HKSCS},
 	{"zh_TW.eucTW"	, C_EUC_TW	, C_BIG5},
 	{"zh_TW.EUC-TW"	, C_EUC_TW	, C_BIG5},
