@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -427,7 +427,7 @@ static gint set_nonblocking_mode(gint fd, gboolean nonblock)
 
 gint sock_set_nonblocking_mode(SockInfo *sock, gboolean nonblock)
 {
-	g_return_val_if_fail(sock != NULL, -1);
+	cm_return_val_if_fail(sock != NULL, -1);
 
 	return set_nonblocking_mode(sock->sock, nonblock);
 }
@@ -451,7 +451,7 @@ static gboolean is_nonblocking_mode(gint fd)
 
 gboolean sock_is_nonblocking_mode(SockInfo *sock)
 {
-	g_return_val_if_fail(sock != NULL, FALSE);
+	cm_return_val_if_fail(sock != NULL, FALSE);
 
 	return is_nonblocking_mode(sock->sock);
 }
@@ -468,11 +468,13 @@ static gboolean sock_check(GSource *source)
 	SockInfo *sock = ((SockSource *)source)->sock;
 	struct timeval timeout = {0, 0};
 	fd_set fds;
-	GIOCondition condition = sock->condition;
+	GIOCondition condition = 0;
         
 	if (!sock || !sock->sock)
 		return FALSE;
 
+	condition = sock->condition;
+
 	FD_ZERO(&fds);
 	FD_SET(sock->sock, &fds);
 
@@ -1407,7 +1409,7 @@ gint sock_read(SockInfo *sock, gchar *buf, gint len)
 {
 	gint ret;
 
-	g_return_val_if_fail(sock != NULL, -1);
+	cm_return_val_if_fail(sock != NULL, -1);
 
 #ifdef USE_GNUTLS
 	if (sock->ssl)
@@ -1459,7 +1461,7 @@ gint sock_write(SockInfo *sock, const gchar *buf, gint len)
 {
 	gint ret;
 
-	g_return_val_if_fail(sock != NULL, -1);
+	cm_return_val_if_fail(sock != NULL, -1);
 
 #ifdef USE_GNUTLS
 	if (sock->ssl)
@@ -1522,7 +1524,7 @@ gint sock_write_all(SockInfo *sock, const gchar *buf, gint len)
 {
 	gint ret;
 
-	g_return_val_if_fail(sock != NULL, -1);
+	cm_return_val_if_fail(sock != NULL, -1);
 
 #ifdef USE_GNUTLS
 	if (sock->ssl)
