@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2009 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -537,7 +537,7 @@ static guint check_cert(gnutls_x509_crt cert)
 	FILE *fp;
 
 	if (claws_ssl_get_cert_file())
-		fp = fopen(claws_ssl_get_cert_file(), "r");
+		fp = g_fopen(claws_ssl_get_cert_file(), "r");
 	else
 		return (guint)-1;
 
