@@ -415,9 +415,6 @@ static const gchar *get_compiled_in_features(void)
 #if HAVE_LIBCOMPFACE
 		   " compface"
 #endif
-#if USE_OPENSSL
-		   " OpenSSL"
-#endif
 #if USE_GNUTLS
 		   " GnuTLS"
 #endif
@@ -433,9 +430,6 @@ static const gchar *get_compiled_in_features(void)
 #if HAVE_LIBETPAN
 		   " libetpan"
 #endif
-#if USE_GNOMEPRINT
-		   " libgnomeprint"
-#endif
 #if HAVE_LIBSM
 		   " libSM"
 #endif
