@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -101,7 +101,7 @@ void custom_header_free(CustomHeader *ch)
 
 gboolean custom_header_is_allowed(const gchar *header)
 {
-	g_return_val_if_fail(header != NULL, FALSE);
+	cm_return_val_if_fail(header != NULL, FALSE);
 
 	if (g_ascii_strcasecmp(header, "Date")         != 0 &&
 	    g_ascii_strcasecmp(header, "From")         != 0 &&
