@@ -1617,8 +1617,17 @@ static void folderview_update_node(FolderView *folderview, GtkCMCTreeNode *node)
 	    folder_has_parent_of_type(item, F_TRASH)) {
 		use_bold = use_color = FALSE;
 	} else if (folder_has_parent_of_type(item, F_QUEUE)) {
-		/* highlight queue folder if there are any messages */
-		use_bold = use_color = (item->total_msgs > 0);
+		GSList *list = folder_item_get_msg_list(item);
+		GSList *cur;
+		use_bold = use_color = FALSE;
+		for (cur = list; cur; cur = cur->next) {
+			MsgInfo *msginfo = (MsgInfo *)cur->data;
+			if (!MSG_IS_DELETED(msginfo->flags)) {
+				/* highlight queue folder if there are any messages */
+				use_bold = use_color = TRUE;
+				break;
+			}
+		}
 	} else {
 		/* if unread messages exist, print with bold font */
 		use_bold = (item->unread_msgs > 0|| item->new_msgs > 0) 
@@ -2165,7 +2174,7 @@ static void folderview_selected(GtkCMCTree *ctree, GtkCMCTreeNode *row,
 		gtk_cmctree_expand(ctree, row);
 
 	/* ungrab the mouse event */
-	if (GTK_WIDGET_HAS_GRAB(ctree)) {
+	if (gtkut_widget_has_grab(GTK_WIDGET(ctree))) {
 		gtk_grab_remove(GTK_WIDGET(ctree));
 		if (gdk_pointer_is_grabbed())
 			gdk_pointer_ungrab(GDK_CURRENT_TIME);
@@ -2621,7 +2630,7 @@ static gchar *last_normalfont = NULL;
 static gchar *last_boldfont = NULL;
 static gboolean last_derive = 0;
 
-void folderview_reflect_prefs_pixmap_theme(FolderView *folderview)
+void folderview_reinit_fonts(FolderView *folderview)
 {
 	/* force reinit */
 	g_free(last_smallfont);
