@@ -96,20 +96,16 @@ GtkCMCTreeNode* gtk_sctree_insert_node        (GtkCMCTree *ctree,
                                              GtkCMCTreeNode *sibling,
                                              gchar *text[],
                                              guint8 spacing,
-                                             GdkPixmap *pixmap_closed,
-                                             GdkBitmap *mask_closed,
-                                             GdkPixmap *pixmap_opened,
-                                             GdkBitmap *mask_opened,
+                                             GdkPixbuf *pixbuf_closed,
+                                             GdkPixbuf *pixbuf_opened,
                                              gboolean is_leaf,
                                              gboolean expanded);
 void        gtk_sctree_set_node_info        (GtkCMCTree *ctree,
                                              GtkCMCTreeNode *node,
                                              const gchar *text,
                                              guint8 spacing,
-                                             GdkPixmap *pixmap_closed,
-                                             GdkBitmap *mask_closed,
-                                             GdkPixmap *pixmap_opened,
-                                             GdkBitmap *mask_opened,
+                                             GdkPixbuf *pixbuf_closed,
+                                             GdkPixbuf *pixbuf_opened,
                                              gboolean is_leaf,
                                              gboolean expanded);
 GtkCMCTreeNode *
