@@ -32,6 +32,7 @@
 #include <gtk/gtk.h>
 #include "gtkshruler.h"
 #include "utils.h"
+#include "gtkutils.h"
 
 #define RULER_HEIGHT          14
 #define MINIMUM_INCR          5
@@ -124,7 +125,7 @@ gtk_shruler_draw_ticks(GtkRuler *ruler)
 	cm_return_if_fail (ruler != NULL);
 	cm_return_if_fail (GTK_IS_HRULER (ruler));
 
-	if (!GTK_WIDGET_DRAWABLE (ruler)) 
+	if (!gtkut_widget_is_drawable (GTK_WIDGET(ruler))) 
 		return;
 
 	widget = GTK_WIDGET (ruler);
