@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -164,6 +164,19 @@ void gtkut_widget_init			(void);
 void gtkut_widget_set_app_icon		(GtkWidget	*widget);
 void gtkut_widget_set_composer_icon	(GtkWidget	*widget);
 
+gboolean gtkut_widget_get_app_paintable	(GtkWidget	*widget);
+gboolean gtkut_widget_get_can_focus	(GtkWidget	*widget);
+gboolean gtkut_widget_get_has_window	(GtkWidget	*widget);
+gboolean gtkut_widget_get_mapped	(GtkWidget	*widget);
+gboolean gtkut_widget_get_realized	(GtkWidget	*widget);
+gboolean gtkut_widget_get_sensitive	(GtkWidget	*widget);
+GtkStateType gtkut_widget_get_state	(GtkWidget	*widget);
+gboolean gtkut_widget_get_visible	(GtkWidget	*widget);
+gboolean gtkut_widget_has_grab		(GtkWidget	*widget);
+gboolean gtkut_widget_has_focus		(GtkWidget	*widget);
+gboolean gtkut_widget_is_drawable	(GtkWidget	*widget);
+gboolean gtkut_widget_is_sensitive	(GtkWidget	*widget);
+
 GtkWidget *gtkut_account_menu_new	(GList			*ac_list,
 				  	 GCallback	 	 callback,
 					 gpointer		 data);
@@ -210,13 +223,12 @@ gboolean gtkut_list_view_select_row(GtkWidget *list, gint row);
 GtkUIManager *gtkut_create_ui_manager(void);
 GtkUIManager *gtkut_ui_manager(void);
 
-#ifdef G_OS_UNIX
 gint
 claws_input_add    (gint	      source,
 		    GdkInputCondition condition,
 		    GdkInputFunction  function,
-		    gpointer	      data);
-#endif
+		    gpointer	      data,
+		    gboolean          is_sock);
 #if GTK_CHECK_VERSION(2,12,0)
 #define CLAWS_TIP_DECL() {}
 #define CLAWS_SET_TIP(widget,tip) { 					\
