@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -67,9 +67,8 @@ void manage_window_destroy(GtkWidget *widget, gpointer data)
 
 void manage_window_set_transient(GtkWindow *window)
 {
-	/* debug_print("manage_window_set_transient(): window = %p, focus_window = %p\n",
-		    window, focus_window); */
-
+#ifndef G_OS_WIN32
 	if (window && focus_window)
 		gtk_window_set_transient_for(window, GTK_WINDOW(focus_window));
+#endif
 }
