@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -140,8 +140,8 @@ void menu_button_position(GtkMenu *menu, gint *x, gint *y, gboolean *push_in,
 	GdkRectangle monitor;
 	gint monitor_num;
 
-	g_return_if_fail(x && y);
- 	g_return_if_fail(GTK_IS_BUTTON(user_data));
+	cm_return_if_fail(x && y);
+ 	cm_return_if_fail(GTK_IS_BUTTON(user_data));
 
 	widget = GTK_WIDGET(user_data);
 
