@@ -69,6 +69,9 @@ struct _QuickSearch
 	gboolean			 in_typing;
 	guint				 press_timeout_id;
 
+	GList				*normal_search_strings;
+	GList				*extended_search_strings;
+	
 	/* dynamic and autorun qs settings are exclusive*/
 	GtkWidget 			 *dynamic_menuitem;
 	GtkWidget 			 *autorun_menuitem;
@@ -102,6 +105,20 @@ static gchar *quicksearch_get_text(QuickSearch * quicksearch)
 	return search_string;
 }
 
+static void quicksearch_set_popdown_strings(QuickSearch *quicksearch)
+{
+	GtkWidget *search_string_entry = quicksearch->search_string_entry;
+
+	combobox_unset_popdown_strings(GTK_COMBO_BOX(search_string_entry));
+
+	if (prefs_common.summary_quicksearch_type == QUICK_SEARCH_EXTENDED)
+		combobox_set_popdown_strings(GTK_COMBO_BOX(search_string_entry),
+			quicksearch->extended_search_strings);	
+	else
+		combobox_set_popdown_strings(GTK_COMBO_BOX(search_string_entry),
+			quicksearch->normal_search_strings);
+}
+
 static void prepare_matcher(QuickSearch *quicksearch)
 {
 	gchar *search_string = quicksearch_get_text(quicksearch);
@@ -202,12 +219,18 @@ static void searchbar_run(QuickSearch *quicksearch, gboolean run_only_if_fast)
 
 	/* add to history */
 	if (!quicksearch->in_typing && search_string && strlen(search_string) != 0) {
-		combobox_unset_popdown_strings(GTK_COMBO_BOX(quicksearch->search_string_entry));
+		if (prefs_common.summary_quicksearch_type == QUICK_SEARCH_EXTENDED)
+			quicksearch->extended_search_strings =
+				add_history(quicksearch->extended_search_strings,
+						search_string);
+		else
+			quicksearch->normal_search_strings =
+				add_history(quicksearch->normal_search_strings,
+						search_string);		
 		prefs_common.summary_quicksearch_history =
 			add_history(prefs_common.summary_quicksearch_history,
 					search_string);
-		combobox_set_popdown_strings(GTK_COMBO_BOX(quicksearch->search_string_entry),
-			prefs_common.summary_quicksearch_history);
+		quicksearch_set_popdown_strings(quicksearch);
 	}
 
 	prepare_matcher(quicksearch);
@@ -317,6 +340,7 @@ static gboolean searchtype_changed(GtkMenuItem *widget, gpointer data)
 
 	/* Show extended search description button, only when Extended is selected */
 	update_extended_buttons(quicksearch);
+	quicksearch_set_popdown_strings(quicksearch);
 
 	if (!search_string || *(search_string) == 0) {
 		g_free(search_string);
@@ -648,9 +672,6 @@ QuickSearch *quicksearch_new()
 
 	search_string_entry = gtk_combo_box_entry_new_text ();
 	gtk_combo_box_set_active(GTK_COMBO_BOX(search_string_entry), -1);
-	if (prefs_common.summary_quicksearch_history)
-		combobox_set_popdown_strings(GTK_COMBO_BOX(search_string_entry),
-			prefs_common.summary_quicksearch_history);
 
 	vbox = gtk_vbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(vbox), search_string_entry, FALSE, FALSE, 0);
@@ -661,11 +682,7 @@ QuickSearch *quicksearch_new()
 
 	search_hbox = gtk_hbox_new(FALSE, 5);
 
-#if GTK_CHECK_VERSION(2, 8, 0)
 	clear_search = gtk_button_new_from_stock(GTK_STOCK_CLEAR);
-#else
-	clear_search = gtk_button_new_with_label(_(" Clear "));
-#endif
 	gtk_box_pack_start(GTK_BOX(search_hbox), clear_search,
 			   FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(clear_search), "clicked",
@@ -674,11 +691,7 @@ QuickSearch *quicksearch_new()
 			     _("Clear the current search"));
 	gtk_widget_show(clear_search);
 
-#if GTK_CHECK_VERSION(2, 8, 0)
 	search_condition_expression = gtk_button_new_from_stock(GTK_STOCK_EDIT);
-#else
-	search_condition_expression = gtk_button_new_with_label(" ... ");
-#endif
 	gtk_box_pack_start(GTK_BOX(search_hbox), search_condition_expression,
 			   FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT (search_condition_expression), "clicked",
@@ -688,11 +701,7 @@ QuickSearch *quicksearch_new()
 			     _("Edit search criteria"));
 	gtk_widget_show(search_condition_expression);
 
-#if GTK_CHECK_VERSION(2, 8, 0)
 	search_description = gtk_button_new_from_stock(GTK_STOCK_INFO);
-#else
-	search_description = gtk_button_new_with_label(_(" Extended Symbols... "));
-#endif
 	gtk_box_pack_start(GTK_BOX(search_hbox), search_description,
 			   FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(search_description), "clicked",
@@ -734,7 +743,9 @@ QuickSearch *quicksearch_new()
 	quicksearch->clear_search = clear_search;
 	quicksearch->in_typing = FALSE;
 	quicksearch->press_timeout_id = -1;
-
+	quicksearch->normal_search_strings = NULL;
+	quicksearch->extended_search_strings = NULL;
+	
 	update_extended_buttons(quicksearch);
 
 	return quicksearch;
@@ -746,18 +757,11 @@ void quicksearch_relayout(QuickSearch *quicksearch)
 	case NORMAL_LAYOUT:
 	case WIDE_LAYOUT:
 	case WIDE_MSGLIST_LAYOUT:
-#if GTK_CHECK_VERSION(2, 8, 0)
 		gtk_button_set_label(GTK_BUTTON(quicksearch->search_description), GTK_STOCK_INFO);
 		gtk_button_set_label(GTK_BUTTON(quicksearch->search_condition_expression), GTK_STOCK_EDIT);
 		gtk_button_set_label(GTK_BUTTON(quicksearch->clear_search), GTK_STOCK_CLEAR);
-#else
-		gtk_button_set_label(GTK_BUTTON(quicksearch->search_description), _(" Extended Symbols... "));
-		gtk_button_set_label(GTK_BUTTON(quicksearch->search_condition_expression), " ... ");
-		gtk_button_set_label(GTK_BUTTON(quicksearch->clear_search), _(" Clear "));
-#endif
 		break;
 	case VERTICAL_LAYOUT:
-#if GTK_CHECK_VERSION(2, 8, 0)
 		gtk_button_set_label(GTK_BUTTON(quicksearch->search_description), "");
 		gtk_button_set_label(GTK_BUTTON(quicksearch->search_condition_expression), "");
 		gtk_button_set_label(GTK_BUTTON(quicksearch->clear_search), "");
@@ -768,11 +772,6 @@ void quicksearch_relayout(QuickSearch *quicksearch)
 			gtk_image_new_from_stock(GTK_STOCK_EDIT, GTK_ICON_SIZE_BUTTON));
 		gtk_button_set_image(GTK_BUTTON(quicksearch->clear_search),
 			gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_BUTTON));
-#else
-		gtk_button_set_label(GTK_BUTTON(quicksearch->search_description), _("Info"));
-		gtk_button_set_label(GTK_BUTTON(quicksearch->search_condition_expression), "...");
-		gtk_button_set_label(GTK_BUTTON(quicksearch->clear_search), _("Clear"));
-#endif
 		break;
 	}
 }
@@ -1351,3 +1350,52 @@ gboolean quicksearch_is_in_typing(QuickSearch *quicksearch)
 {
 	return quicksearch->in_typing;
 }
+
+void quicksearch_set_search_strings(QuickSearch *quicksearch)
+{
+	GList *strings = prefs_common.summary_quicksearch_history;
+	gchar *newstr = NULL;
+	MatcherList *matcher_list = NULL;
+
+	if (!strings)
+		return;
+
+	matcher_parser_disable_warnings(TRUE);
+	
+	do {
+		newstr = expand_search_string((gchar *) strings->data);
+		if (newstr && newstr[0] != '\0') {
+			if (!strchr(newstr, ' ')) {
+				quicksearch->normal_search_strings =
+					g_list_append(
+						quicksearch->normal_search_strings,
+						strings->data);
+				g_free(newstr);
+				continue;
+			}
+			
+			matcher_list = matcher_parser_get_cond(newstr, FALSE);
+			g_free(newstr);
+			
+			if (matcher_list) {
+				quicksearch->extended_search_strings =
+					g_list_prepend(
+						quicksearch->extended_search_strings,
+						g_strdup(strings->data));
+				matcherlist_free(matcher_list);
+			} else
+				quicksearch->normal_search_strings =
+					g_list_prepend(
+						quicksearch->normal_search_strings,
+						g_strdup(strings->data));
+		}
+	
+	} while ((strings = g_list_next(strings)) != NULL);
+
+	matcher_parser_disable_warnings(FALSE);	
+
+	quicksearch->normal_search_strings = g_list_reverse(quicksearch->normal_search_strings);
+	quicksearch->extended_search_strings = g_list_reverse(quicksearch->extended_search_strings);
+
+	quicksearch_set_popdown_strings(quicksearch);
+}
