@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2009 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -136,7 +136,7 @@ static GtkWidget *cert_presenter(SSLCertificate *cert)
 
 	memset(buf, 0, sizeof(buf));
 	if (exp_time_t > 0) {
-		strftime(buf, sizeof(buf)-1, prefs_common.date_format, localtime_r(&exp_time_t, &lt));
+		fast_strftime(buf, sizeof(buf)-1, prefs_common.date_format, localtime_r(&exp_time_t, &lt));
 		exp_date = (*buf) ? g_strdup(buf):g_strdup("?");
 	} else
 		exp_date = g_strdup("");
