@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Match Grun and the Claws Mail team
+ * Copyright (C) 2001-2009 Match Grun and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ LdifFile *ldif_create() {
  * \param value    Value of access flag.
  */
 void ldif_set_file( LdifFile *ldifFile, const gchar *value ) {
-	g_return_if_fail( ldifFile != NULL );
+	cm_return_if_fail( ldifFile != NULL );
 
 	if( ldifFile->path ) {
 		if( strcmp( ldifFile->path, value ) != 0 )
@@ -83,7 +83,7 @@ void ldif_set_file( LdifFile *ldifFile, const gchar *value ) {
  * \param value    File specification.
  */
 void ldif_set_accessed( LdifFile *ldifFile, const gboolean value ) {
-	g_return_if_fail( ldifFile != NULL );
+	cm_return_if_fail( ldifFile != NULL );
 	ldifFile->accessFlag = value;
 }
 
@@ -123,7 +123,7 @@ static void ldif_free_fieldrec( Ldif_FieldRec *rec ) {
  *              named.
  */
 void ldif_field_set_name( Ldif_FieldRec *rec, const gchar *value ) {
-	g_return_if_fail( rec != NULL );
+	cm_return_if_fail( rec != NULL );
 
 	if( ! rec->reserved ) {
 		rec->userName = mgu_replace_string( rec->userName, value );
@@ -138,7 +138,7 @@ void ldif_field_set_name( Ldif_FieldRec *rec, const gchar *value ) {
  *              fields cannot be unselected.
  */
 void ldif_field_set_selected( Ldif_FieldRec *rec, const gboolean value ) {
-	g_return_if_fail( rec != NULL );
+	cm_return_if_fail( rec != NULL );
 
 	if( ! rec->reserved ) {
 		rec->selected = value;
@@ -151,7 +151,7 @@ void ldif_field_set_selected( Ldif_FieldRec *rec, const gboolean value ) {
  * \param rec   LDIF field object.
  */
 void ldif_field_toggle( Ldif_FieldRec *rec ) {
-	g_return_if_fail( rec != NULL );
+	cm_return_if_fail( rec != NULL );
 
 	if( ! rec->reserved ) {
 		rec->selected = !rec->selected;
@@ -177,7 +177,7 @@ static gint ldif_hash_free_vis( gpointer key, gpointer value, gpointer data ) {
  * \param ldifFile LDIF import control object.
  */
 void ldif_free( LdifFile *ldifFile ) {
-	g_return_if_fail( ldifFile != NULL );
+	cm_return_if_fail( ldifFile != NULL );
 
 	/* Close file */
 	if( ldifFile->file ) fclose( ldifFile->file );
@@ -234,7 +234,7 @@ static gint ldif_open_file( LdifFile* ldifFile ) {
  * \param  ldifFile LDIF import control object.
  */
 static void ldif_close_file( LdifFile *ldifFile ) {
-	g_return_if_fail( ldifFile != NULL );
+	cm_return_if_fail( ldifFile != NULL );
 	if( ldifFile->file ) fclose( ldifFile->file );
 	ldifFile->file = NULL;
 }
@@ -250,8 +250,10 @@ static gchar *ldif_get_line( LdifFile *ldifFile ) {
 	int i = 0;
 	int cur_alloc = LDIFBUFSIZE;
 
-	if( feof( ldifFile->file ) ) 
+	if( feof( ldifFile->file ) ) {
+		g_free(buf);
 		return NULL;
+	}
 
 	while( i < cur_alloc-1 ) {
 		ch = fgetc( ldifFile->file );
@@ -293,7 +295,7 @@ static gchar *ldif_get_tagname( char* line, gboolean *flag64 ) {
 	gchar *tag = NULL;
 	gchar *lptr = line;
 	gchar *sptr = NULL;
-	gchar *down = NULL;
+	
 	while( *lptr++ ) {
 		/* Check for language tag */
 		if( *lptr == LDIF_LANG_TAG ) {
@@ -314,9 +316,7 @@ static gchar *ldif_get_tagname( char* line, gboolean *flag64 ) {
 
 			tag = g_strndup( line, len+1 );
 			tag[ len ] = '\0';
-			down = g_utf8_strdown( tag, -1 );
-			g_free(tag);
-			return down;
+                        return tag;
 		}
 	}
 	return tag;
@@ -923,7 +923,7 @@ static void ldif_read_tag_list( LdifFile *ldifFile ) {
  * \return Status code.
  */
 gint ldif_import_data( LdifFile *ldifFile, AddressCache *cache ) {
-	g_return_val_if_fail( ldifFile != NULL, MGU_BAD_ARGS );
+	cm_return_val_if_fail( ldifFile != NULL, MGU_BAD_ARGS );
 	ldifFile->retVal = MGU_SUCCESS;
 	addrcache_clear( cache );
 	cache->dataRead = FALSE;
@@ -947,7 +947,7 @@ gint ldif_import_data( LdifFile *ldifFile, AddressCache *cache ) {
  * \return Status code.
  */
 gint ldif_read_tags( LdifFile *ldifFile ) {
-	g_return_val_if_fail( ldifFile != NULL, MGU_BAD_ARGS );
+	cm_return_val_if_fail( ldifFile != NULL, MGU_BAD_ARGS );
 	ldifFile->retVal = MGU_SUCCESS;
 	if( ldifFile->dirtyFlag ) {
 		ldif_open_file( ldifFile );
@@ -973,7 +973,7 @@ gint ldif_read_tags( LdifFile *ldifFile ) {
 GList *ldif_get_fieldlist( LdifFile *ldifFile ) {
 	GList *list = NULL;
 
-	g_return_val_if_fail( ldifFile != NULL, NULL );
+	cm_return_val_if_fail( ldifFile != NULL, NULL );
 	if( ldifFile->hashFields ) {
 		ldifFile->tempList = NULL;
 		g_hash_table_foreach( ldifFile->hashFields, ldif_hash2list_vis, ldifFile );
