@@ -904,12 +904,6 @@ static void main_dump_features_list(gboolean show_debug_only)
 	else
 		g_print(" libetpan %d.%d\n", LIBETPAN_VERSION_MAJOR, LIBETPAN_VERSION_MINOR);
 #endif
-#if USE_GNOMEPRINT
-	if (show_debug_only)
-		debug_print(" gnomeprint\n");
-	else
-		g_print(" gnomeprint\n");
-#endif
 #if HAVE_LIBSM
 	if (show_debug_only)
 		debug_print(" libsm\n");
@@ -1456,6 +1450,7 @@ int main(int argc, char *argv[])
 	folderview_set(folderview);
 
 	prefs_matcher_read_config();
+	quicksearch_set_search_strings(mainwin->summaryview->quicksearch);
 
 	/* make one all-folder processing before using claws */
 	main_window_cursor_wait(mainwin);
@@ -1702,6 +1697,7 @@ static void save_all_caches(FolderItem *item, gpointer data)
 static void exit_claws(MainWindow *mainwin)
 {
 	gchar *filename;
+	gboolean have_connectivity;
 
 	sc_exiting = TRUE;
 
@@ -1744,9 +1740,14 @@ static void exit_claws(MainWindow *mainwin)
 	close_log_file(LOG_PROTOCOL);
 	close_log_file(LOG_DEBUG_FILTERING);
 
+#ifdef HAVE_NETWORKMANAGER_SUPPORT
+	have_connectivity = networkmanager_is_online(NULL); 
+#else
+	have_connectivity = TRUE;
+#endif
 #ifdef HAVE_LIBETPAN
-	imap_main_done();
-	nntp_main_done();
+	imap_main_done(have_connectivity);
+	nntp_main_done(have_connectivity);
 #endif
 	/* delete crashfile */
 	if (!cmd.crash)
