@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Hiroyuki Yamamoto & The Claws Mail Team
+ * Copyright (C) 1999-2009 Hiroyuki Yamamoto & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #include "codeconv.h"
 #include "timing.h"
 #include "tags.h"
+#include "prefs_common.h"
 
 #ifdef HAVE_FWRITE_UNLOCKED
 #define SC_FWRITE fwrite_unlocked
@@ -70,7 +71,6 @@
 	 ((x[3]&0xff) << 24))
 
 static gboolean msgcache_use_mmap_read = TRUE;
-static gboolean msgcache_use_mmap_write = FALSE;
 
 #else
 #define bswap_32(x) (x)
@@ -88,7 +88,6 @@ static gboolean msgcache_use_mmap_write = FALSE;
 	 ((x[3]&0xff) << 24))
 
 static gboolean msgcache_use_mmap_read = TRUE;
-static gboolean msgcache_use_mmap_write = FALSE;
 #endif
 
 static gboolean swapping = TRUE;
@@ -146,7 +145,7 @@ static gboolean msgcache_msginfo_free_func(gpointer num, gpointer msginfo, gpoin
 
 void msgcache_destroy(MsgCache *cache)
 {
-	g_return_if_fail(cache != NULL);
+	cm_return_if_fail(cache != NULL);
 
 	g_hash_table_foreach_remove(cache->msgnum_table, msgcache_msginfo_free_func, NULL);
 	g_hash_table_destroy(cache->msgid_table);
@@ -158,8 +157,8 @@ void msgcache_add_msg(MsgCache *cache, MsgInfo *msginfo)
 {
 	MsgInfo *newmsginfo;
 
-	g_return_if_fail(cache != NULL);
-	g_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(cache != NULL);
+	cm_return_if_fail(msginfo != NULL);
 
 	newmsginfo = procmsg_msginfo_new_ref(msginfo);
 	g_hash_table_insert(cache->msgnum_table, &newmsginfo->msgnum, newmsginfo);
@@ -168,6 +167,8 @@ void msgcache_add_msg(MsgCache *cache, MsgInfo *msginfo)
 	cache->memusage += procmsg_msginfo_memusage(msginfo);
 	cache->last_access = time(NULL);
 
+	msginfo->folder->cache_dirty = TRUE;
+
 	debug_print("Cache size: %d messages, %u bytes\n", g_hash_table_size(cache->msgnum_table), cache->memusage);
 }
 
@@ -175,8 +176,7 @@ void msgcache_remove_msg(MsgCache *cache, guint msgnum)
 {
 	MsgInfo *msginfo;
 
-	g_return_if_fail(cache != NULL);
-	g_return_if_fail(msgnum > 0);
+	cm_return_if_fail(cache != NULL);
 
 	msginfo = (MsgInfo *) g_hash_table_lookup(cache->msgnum_table, &msgnum);
 	if(!msginfo)
@@ -189,6 +189,8 @@ void msgcache_remove_msg(MsgCache *cache, guint msgnum)
 	procmsg_msginfo_free(msginfo);
 	cache->last_access = time(NULL);
 
+	msginfo->folder->cache_dirty = TRUE;
+
 	debug_print("Cache size: %d messages, %u bytes\n", g_hash_table_size(cache->msgnum_table), cache->memusage);
 }
 
@@ -196,8 +198,8 @@ void msgcache_update_msg(MsgCache *cache, MsgInfo *msginfo)
 {
 	MsgInfo *oldmsginfo, *newmsginfo;
 	
-	g_return_if_fail(cache != NULL);
-	g_return_if_fail(msginfo != NULL);
+	cm_return_if_fail(cache != NULL);
+	cm_return_if_fail(msginfo != NULL);
 
 	oldmsginfo = g_hash_table_lookup(cache->msgnum_table, &msginfo->msgnum);
 	if(oldmsginfo && oldmsginfo->msgid) 
@@ -217,6 +219,8 @@ void msgcache_update_msg(MsgCache *cache, MsgInfo *msginfo)
 	
 	debug_print("Cache size: %d messages, %u bytes\n", g_hash_table_size(cache->msgnum_table), cache->memusage);
 
+	msginfo->folder->cache_dirty = TRUE;
+
 	return;
 }
 
@@ -224,7 +228,7 @@ MsgInfo *msgcache_get_msg(MsgCache *cache, guint num)
 {
 	MsgInfo *msginfo;
 
-	g_return_val_if_fail(cache != NULL, NULL);
+	cm_return_val_if_fail(cache != NULL, NULL);
 
 	msginfo = g_hash_table_lookup(cache->msgnum_table, &num);
 	if(!msginfo)
@@ -238,8 +242,8 @@ MsgInfo *msgcache_get_msg_by_id(MsgCache *cache, const gchar *msgid)
 {
 	MsgInfo *msginfo;
 	
-	g_return_val_if_fail(cache != NULL, NULL);
-	g_return_val_if_fail(msgid != NULL, NULL);
+	cm_return_val_if_fail(cache != NULL, NULL);
+	cm_return_val_if_fail(msgid != NULL, NULL);
 
 	msginfo = g_hash_table_lookup(cache->msgid_table, msgid);
 	if(!msginfo)
@@ -261,7 +265,7 @@ MsgInfoList *msgcache_get_msg_list(MsgCache *cache)
 {
 	MsgInfoList *msg_list = NULL;
 	START_TIMING("");
-	g_return_val_if_fail(cache != NULL, NULL);
+	cm_return_val_if_fail(cache != NULL, NULL);
 
 	g_hash_table_foreach((GHashTable *)cache->msgnum_table, msgcache_get_msg_list_func, (gpointer)&msg_list);	
 	cache->last_access = time(NULL);
@@ -273,14 +277,14 @@ MsgInfoList *msgcache_get_msg_list(MsgCache *cache)
 
 time_t msgcache_get_last_access_time(MsgCache *cache)
 {
-	g_return_val_if_fail(cache != NULL, 0);
+	cm_return_val_if_fail(cache != NULL, 0);
 	
 	return cache->last_access;
 }
 
 gint msgcache_get_memory_usage(MsgCache *cache)
 {
-	g_return_val_if_fail(cache != NULL, 0);
+	cm_return_val_if_fail(cache != NULL, 0);
 
 	return cache->memusage;
 }
@@ -314,15 +318,25 @@ gint msgcache_get_memory_usage(MsgCache *cache)
 		n = swapping ? bswap_32(idata) : (idata);\
 }
 
-#define GET_CACHE_DATA_INT(n) \
-{ \
-	n = (swapping ? (MMAP_TO_GUINT32_SWAPPED(walk_data)):(MMAP_TO_GUINT32(walk_data))); \
-	walk_data += 4;	rem_len -= 4;			\
+#define GET_CACHE_DATA_INT(n)									\
+{												\
+	if (rem_len < 4) {									\
+		g_print("error at rem_len:%d\n", rem_len);					\
+		error = TRUE;									\
+		goto bail_err;									\
+	}											\
+	n = (swapping ? (MMAP_TO_GUINT32_SWAPPED(walk_data)):(MMAP_TO_GUINT32(walk_data))); 	\
+	walk_data += 4;	rem_len -= 4;								\
 }
 
 #define GET_CACHE_DATA(data, total_len) \
 { \
 	GET_CACHE_DATA_INT(tmp_len);	\
+	if (rem_len < tmp_len) {								\
+		g_print("error at rem_len:%d (tmp_len %d)\n", rem_len, tmp_len);		\
+		error = TRUE;									\
+		goto bail_err;									\
+	}											\
 	if ((tmp_len = msgcache_get_cache_data_str(walk_data, &data, tmp_len, conv)) < 0) { \
 		g_print("error at rem_len:%d\n", rem_len);\
 		procmsg_msginfo_free(msginfo); \
@@ -391,7 +405,7 @@ static FILE *msgcache_open_data_file(const gchar *file, guint version,
 	FILE *fp;
 	gint32 data_ver;
 
-	g_return_val_if_fail(file != NULL, NULL);
+	cm_return_val_if_fail(file != NULL, NULL);
 
 	if (mode == DATA_WRITE) {
 		int w_err = 0, wrote = 0;
@@ -566,8 +580,8 @@ MsgCache *msgcache_read_cache(FolderItem *item, const gchar *cache_file)
 	char *cache_data = NULL;
 	struct stat st;
 
-	g_return_val_if_fail(cache_file != NULL, NULL);
-	g_return_val_if_fail(item != NULL, NULL);
+	cm_return_val_if_fail(cache_file != NULL, NULL);
+	cm_return_val_if_fail(item != NULL, NULL);
 
 	swapping = TRUE;
 
@@ -775,6 +789,7 @@ bail_err:
 
 	debug_print("done. (%d items read)\n", g_hash_table_size(cache->msgnum_table));
 	debug_print("Cache size: %d messages, %u bytes\n", g_hash_table_size(cache->msgnum_table), cache->memusage);
+
 	return cache;
 }
 
@@ -787,7 +802,8 @@ void msgcache_read_mark(MsgCache *cache, const gchar *mark_file)
 	gint map_len = -1;
 	char *cache_data = NULL;
 	struct stat st;
-	
+	gboolean error;
+
 	swapping = TRUE;
 
 	/* In case we can't open the mark file with MARK_VERSION, check if we can open it with the
@@ -860,6 +876,7 @@ void msgcache_read_mark(MsgCache *cache, const gchar *mark_file)
 			}
 		}	
 	}
+bail_err:
 	fclose(fp);
 }
 
@@ -871,7 +888,8 @@ void msgcache_read_tags(MsgCache *cache, const gchar *tags_file)
 	gint map_len = -1;
 	char *cache_data = NULL;
 	struct stat st;
-	
+	gboolean error = FALSE;
+
 	swapping = TRUE;
 
 	/* In case we can't open the mark file with MARK_VERSION, check if we can open it with the
@@ -965,6 +983,7 @@ void msgcache_read_tags(MsgCache *cache, const gchar *tags_file)
 			}
 		}
 	}
+bail_err:
 	fclose(fp);
 }
 
@@ -1002,39 +1021,6 @@ static int msgcache_write_cache(MsgInfo *msginfo, FILE *fp)
 	return w_err ? -1 : wrote;
 }
 
-static int msgcache_write_mmap_cache(MsgInfo *msginfo, char *walk_data)
-{
-	MsgTmpFlags flags = msginfo->flags.tmp_flags & MSG_CACHED_FLAG_MASK;
-	GSList *cur;
-	int wrote = 0;
-
-	PUT_CACHE_DATA_INT(msginfo->msgnum);
-	PUT_CACHE_DATA_INT(msginfo->size);
-	PUT_CACHE_DATA_INT(msginfo->mtime);
-	PUT_CACHE_DATA_INT(msginfo->date_t);
-	PUT_CACHE_DATA_INT(flags);
-	PUT_CACHE_DATA(msginfo->fromname);
-
-	PUT_CACHE_DATA(msginfo->date);
-	PUT_CACHE_DATA(msginfo->from);
-	PUT_CACHE_DATA(msginfo->to);
-	PUT_CACHE_DATA(msginfo->cc);
-	PUT_CACHE_DATA(msginfo->newsgroups);
-	PUT_CACHE_DATA(msginfo->subject);
-	PUT_CACHE_DATA(msginfo->msgid);
-	PUT_CACHE_DATA(msginfo->inreplyto);
-	PUT_CACHE_DATA(msginfo->xref);
-	PUT_CACHE_DATA_INT(msginfo->planned_download);
-	PUT_CACHE_DATA_INT(msginfo->total_size);
-        
-	PUT_CACHE_DATA_INT(g_slist_length(msginfo->references));
-
-	for (cur = msginfo->references; cur != NULL; cur = cur->next) {
-		PUT_CACHE_DATA((gchar *)cur->data);
-	}
-	return wrote;
-}
-
 static int msgcache_write_flags(MsgInfo *msginfo, FILE *fp)
 {
 	MsgPermFlags flags = msginfo->flags.perm_flags;
@@ -1061,40 +1047,11 @@ static int msgcache_write_tags(MsgInfo *msginfo, FILE *fp)
 	return w_err ? -1 : wrote;
 }
 
-static int msgcache_write_mmap_flags(MsgInfo *msginfo, char *walk_data)
-{
-	MsgPermFlags flags = msginfo->flags.perm_flags;
-	int wrote = 0;
-
-	PUT_CACHE_DATA_INT(msginfo->msgnum);
-	PUT_CACHE_DATA_INT(flags);
-	return wrote;
-}
-
-static int msgcache_write_mmap_tags(MsgInfo *msginfo, char *walk_data)
-{
-	GSList *cur = msginfo->tags;
-	int wrote = 0;
-	
-	PUT_CACHE_DATA_INT(msginfo->msgnum);
-	for (; cur; cur = cur->next) {
-		gint id = GPOINTER_TO_INT(cur->data);
-		if (tags_get_tag(id) != NULL) {
-			PUT_CACHE_DATA_INT(id);
-		}
-	}
-	PUT_CACHE_DATA_INT(-1);
-	return wrote;
-}
-
 struct write_fps
 {
 	FILE *cache_fp;
 	FILE *mark_fp;
 	FILE *tags_fp;
-	char *cache_data;
-	char *mark_data;
-	char *tags_data;
 	int error;
 	guint cache_size;
 	guint mark_size;
@@ -1110,41 +1067,27 @@ static void msgcache_write_func(gpointer key, gpointer value, gpointer user_data
 	msginfo = (MsgInfo *)value;
 	write_fps = user_data;
 
-	tmp = msgcache_write_cache(msginfo, write_fps->cache_fp);
-	if (tmp < 0)
-		write_fps->error = 1;
-	else
-		write_fps->cache_size += tmp;
+	if (write_fps->cache_fp) {
+		tmp = msgcache_write_cache(msginfo, write_fps->cache_fp);
+		if (tmp < 0)
+			write_fps->error = 1;
+		else
+			write_fps->cache_size += tmp;
+	}
+	if (write_fps->mark_fp) {
 	tmp= msgcache_write_flags(msginfo, write_fps->mark_fp);
-	if (tmp < 0)
-		write_fps->error = 1;
-	else
-		write_fps->mark_size += tmp;
-	tmp = msgcache_write_tags(msginfo, write_fps->tags_fp);
-	if (tmp < 0)
-		write_fps->error = 1;
-	else
-		write_fps->tags_size += tmp;
-}
-
-static void msgcache_write_mmap_func(gpointer key, gpointer value, gpointer user_data)
-{
-	MsgInfo *msginfo;
-	struct write_fps *write_fps;
-	int tmp;
-
-	msginfo = (MsgInfo *)value;
-	write_fps = user_data;
-
-	tmp = msgcache_write_mmap_cache(msginfo, write_fps->cache_data);
-	write_fps->cache_size += tmp;
-	write_fps->cache_data += tmp;
-	tmp = msgcache_write_mmap_flags(msginfo, write_fps->mark_data);
-	write_fps->mark_size += tmp;
-	write_fps->mark_data += tmp;
-	tmp = msgcache_write_mmap_tags(msginfo, write_fps->tags_data);
-	write_fps->tags_size += tmp;
-	write_fps->tags_data += tmp;
+		if (tmp < 0)
+			write_fps->error = 1;
+		else
+			write_fps->mark_size += tmp;
+		}
+	if (write_fps->tags_fp) {
+		tmp = msgcache_write_tags(msginfo, write_fps->tags_fp);
+		if (tmp < 0)
+			write_fps->error = 1;
+		else
+			write_fps->tags_size += tmp;
+	}
 }
 
 gint msgcache_write(const gchar *cache_file, const gchar *mark_file, const gchar *tags_file, MsgCache *cache)
@@ -1152,16 +1095,9 @@ gint msgcache_write(const gchar *cache_file, const gchar *mark_file, const gchar
 	struct write_fps write_fps;
 	gchar *new_cache, *new_mark, *new_tags;
 	int w_err = 0, wrote = 0;
-	gint map_len = -1;
-	char *cache_data = NULL;
-	char *mark_data = NULL;
-	char *tags_data = NULL;
 
 	START_TIMING("");
-	g_return_val_if_fail(cache_file != NULL, -1);
-	g_return_val_if_fail(mark_file != NULL, -1);
-	g_return_val_if_fail(tags_file != NULL, -1);
-	g_return_val_if_fail(cache != NULL, -1);
+	cm_return_val_if_fail(cache != NULL, -1);
 
 	new_cache = g_strconcat(cache_file, ".new", NULL);
 	new_mark  = g_strconcat(mark_file, ".new", NULL);
@@ -1172,16 +1108,21 @@ gint msgcache_write(const gchar *cache_file, const gchar *mark_file, const gchar
 	write_fps.mark_size = 0;
 	write_fps.tags_size = 0;
 
-	write_fps.cache_fp = msgcache_open_data_file(new_cache, CACHE_VERSION,
-		DATA_WRITE, NULL, 0);
-	if (write_fps.cache_fp == NULL) {
-		g_free(new_cache);
-		g_free(new_mark);
-		g_free(new_tags);
-		return -1;
-	}
+	/* open files and write headers */
 
-	WRITE_CACHE_DATA(CS_UTF_8, write_fps.cache_fp);
+	if (cache_file) {
+		write_fps.cache_fp = msgcache_open_data_file(new_cache, CACHE_VERSION,
+			DATA_WRITE, NULL, 0);
+		if (write_fps.cache_fp == NULL) {
+			g_free(new_cache);
+			g_free(new_mark);
+			g_free(new_tags);
+			return -1;
+		}
+		WRITE_CACHE_DATA(CS_UTF_8, write_fps.cache_fp);
+	} else {
+		write_fps.cache_fp = NULL;
+	}
 
 	if (w_err != 0) {
 		g_warning("failed to write charset\n");
@@ -1193,170 +1134,98 @@ gint msgcache_write(const gchar *cache_file, const gchar *mark_file, const gchar
 		return -1;
 	}
 
-	write_fps.mark_fp = msgcache_open_data_file(new_mark, MARK_VERSION,
-		DATA_WRITE, NULL, 0);
-	if (write_fps.mark_fp == NULL) {
-		fclose(write_fps.cache_fp);
-		claws_unlink(new_cache);
-		g_free(new_cache);
-		g_free(new_mark);
-		g_free(new_tags);
-		return -1;
+	if (mark_file) {
+		write_fps.mark_fp = msgcache_open_data_file(new_mark, MARK_VERSION,
+			DATA_WRITE, NULL, 0);
+		if (write_fps.mark_fp == NULL) {
+			fclose(write_fps.cache_fp);
+			claws_unlink(new_cache);
+			g_free(new_cache);
+			g_free(new_mark);
+			g_free(new_tags);
+			return -1;
+		}
+	} else {
+		write_fps.mark_fp = NULL;
 	}
 
-	write_fps.tags_fp = msgcache_open_data_file(new_tags, TAGS_VERSION,
-		DATA_WRITE, NULL, 0);
-	if (write_fps.tags_fp == NULL) {
-		fclose(write_fps.cache_fp);
-		fclose(write_fps.mark_fp);
-		claws_unlink(new_cache);
-		claws_unlink(new_mark);
-		g_free(new_cache);
-		g_free(new_mark);
-		g_free(new_tags);
-		return -1;
+	if (tags_file) {
+		write_fps.tags_fp = msgcache_open_data_file(new_tags, TAGS_VERSION,
+			DATA_WRITE, NULL, 0);
+		if (write_fps.tags_fp == NULL) {
+			fclose(write_fps.cache_fp);
+			fclose(write_fps.mark_fp);
+			claws_unlink(new_cache);
+			claws_unlink(new_mark);
+			g_free(new_cache);
+			g_free(new_mark);
+			g_free(new_tags);
+			return -1;
+		}
+	} else {
+		write_fps.tags_fp = NULL;
 	}
 
 	debug_print("\tWriting message cache to %s and %s...\n", new_cache, new_mark);
 
-	if (change_file_mode_rw(write_fps.cache_fp, new_cache) < 0)
+	if (write_fps.cache_fp && change_file_mode_rw(write_fps.cache_fp, new_cache) < 0)
 		FILE_OP_ERROR(new_cache, "chmod");
 
-	write_fps.cache_size = ftell(write_fps.cache_fp);
-	write_fps.mark_size = ftell(write_fps.mark_fp);
-	write_fps.tags_size = ftell(write_fps.tags_fp);
+	/* headers written, note file size */
+	if (write_fps.cache_fp)
+		write_fps.cache_size = ftell(write_fps.cache_fp);
+	if (write_fps.mark_fp)
+		write_fps.mark_size = ftell(write_fps.mark_fp);
+	if (write_fps.tags_fp)
+		write_fps.tags_size = ftell(write_fps.tags_fp);
 
-	if (msgcache_use_mmap_write && cache->memusage > 0) {
-		map_len = cache->memusage;
-		if (ftruncate(fileno(write_fps.cache_fp), (off_t)map_len) == 0) {
-
-#ifdef G_OS_WIN32
-			cache_data = NULL;
-			HANDLE hFile, hMapping;
-			hFile = (HANDLE) _get_osfhandle (fileno(write_fps.cache_fp));
-			if (hFile == (HANDLE) -1)
-				goto w32_fail3;
-			hMapping = CreateFileMapping(hFile, NULL, PAGE_READWRITE, 0, 0, NULL);
-			if (!hMapping)
-				goto w32_fail3;
-			cache_data = (unsigned char *)MapViewOfFile(hMapping, FILE_MAP_COPY, 0, 0, 0);
-			CloseHandle (hMapping);
-		w32_fail3:
-			;
-#else
-			cache_data = mmap(NULL, map_len, PROT_WRITE, MAP_SHARED, 
-				fileno(write_fps.cache_fp), 0);
-#endif
-		}
-		if (cache_data != NULL && cache_data != MAP_FAILED) {
-			if (ftruncate(fileno(write_fps.mark_fp), (off_t)map_len) == 0) {
-#ifdef G_OS_WIN32
-				mark_data = NULL;
-				HANDLE hFile, hMapping;
-				hFile = (HANDLE) _get_osfhandle (fileno(write_fps.mark_fp));
-				if (hFile == (HANDLE) -1)
-					goto w32_fail4;
-				hMapping = CreateFileMapping(hFile, NULL, PAGE_READWRITE, 0, 0, NULL);
-				if (!hMapping)
-					goto w32_fail4;
-				mark_data = (unsigned char *)MapViewOfFile(hMapping, FILE_MAP_COPY, 0, 0, 0);
-				CloseHandle (hMapping);
-			w32_fail4:
-				;
-#else
-				mark_data = mmap(NULL, map_len, PROT_WRITE, MAP_SHARED, 
-					fileno(write_fps.mark_fp), 0);
-#endif
-			} 
-			if (mark_data == NULL || mark_data == MAP_FAILED) {
-#ifdef G_OS_WIN32
-				UnmapViewOfFile((void*) cache_data);
-#else
-				munmap(cache_data, map_len);
-#endif
-				cache_data = NULL;
-			} else {
-				if (ftruncate(fileno(write_fps.tags_fp), (off_t)map_len) == 0) {
-#ifdef G_OS_WIN32
-						tags_data = NULL;
-						HANDLE hFile, hMapping;
-						hFile = (HANDLE) _get_osfhandle (fileno(write_fps.tags_fp));
-						if (hFile == (HANDLE) -1)
-							goto w32_fail5;
-						hMapping = CreateFileMapping(hFile, NULL, PAGE_READWRITE, 0, 0, NULL);
-						if (!hMapping)
-							goto w32_fail5;
-						tags_data = (unsigned char *)MapViewOfFile(hMapping, FILE_MAP_COPY, 0, 0, 0);
-						CloseHandle (hMapping);
-					w32_fail5:
-						;
-#else
-					tags_data = mmap(NULL, map_len, PROT_WRITE, MAP_SHARED, 
-						fileno(write_fps.tags_fp), 0);
-#endif
-				} 
-				if (tags_data == NULL || tags_data == MAP_FAILED) {
-#ifdef G_OS_WIN32
-					UnmapViewOfFile((void*) cache_data);
-					UnmapViewOfFile((void*) mark_data);
-#else
-					munmap(cache_data, map_len);
-					munmap(mark_data, map_len);
-#endif
-					cache_data = NULL;
-					mark_data = NULL;
-				} 
-			}
-		}
-	}
-
-	if (cache_data != NULL && cache_data != MAP_FAILED) {
-		write_fps.cache_data = cache_data + ftell(write_fps.cache_fp);
-		write_fps.mark_data = mark_data + ftell(write_fps.mark_fp);
-		write_fps.tags_data = mark_data + ftell(write_fps.tags_fp);
-		g_hash_table_foreach(cache->msgnum_table, msgcache_write_mmap_func, (gpointer)&write_fps);
-#ifdef G_OS_WIN32
-		UnmapViewOfFile((void*) cache_data);
-		UnmapViewOfFile((void*) mark_data);
-		UnmapViewOfFile((void*) tags_data);
-#else
-		munmap(cache_data, map_len);
-		munmap(mark_data, map_len);
-		munmap(tags_data, map_len);
-#endif
-		ftruncate(fileno(write_fps.cache_fp), write_fps.cache_size);
-		ftruncate(fileno(write_fps.mark_fp), write_fps.mark_size);
-		ftruncate(fileno(write_fps.tags_fp), write_fps.tags_size);
-	} else {
 #ifdef HAVE_FWRITE_UNLOCKED
+	/* lock files for write once (instead of once per fwrite) */
+	if (write_fps.cache_fp)
 		flockfile(write_fps.cache_fp);
+	if (write_fps.mark_fp)
 		flockfile(write_fps.mark_fp);
+	if (write_fps.tags_fp)
 		flockfile(write_fps.tags_fp);
 #endif
-		g_hash_table_foreach(cache->msgnum_table, msgcache_write_func, (gpointer)&write_fps);
+	/* write data to the files */
+	g_hash_table_foreach(cache->msgnum_table, msgcache_write_func, (gpointer)&write_fps);
 #ifdef HAVE_FWRITE_UNLOCKED
-		funlockfile(write_fps.mark_fp);
+	/* unlock files */
+	if (write_fps.cache_fp)
 		funlockfile(write_fps.cache_fp);
+	if (write_fps.mark_fp)
+		funlockfile(write_fps.mark_fp);
+	if (write_fps.tags_fp)
 		funlockfile(write_fps.tags_fp);
 #endif
-	}
-	
-	fflush(write_fps.cache_fp);
-	fflush(write_fps.mark_fp);
-	fflush(write_fps.tags_fp);
+	/* flush buffers */
+	if (write_fps.cache_fp)
+		write_fps.error |= (fflush(write_fps.cache_fp) != 0);
+	if (write_fps.mark_fp)
+		write_fps.error |= (fflush(write_fps.mark_fp) != 0);
+	if (write_fps.tags_fp)
+		write_fps.error |= (fflush(write_fps.tags_fp) != 0);
 
-#if 0
-	fsync(fileno(write_fps.cache_fp));
-	fsync(fileno(write_fps.mark_fp));
-	fsync(fileno(write_fps.tags_fp));
-#endif
+	/* sync to filesystem */
+	if (prefs_common.flush_metadata && write_fps.cache_fp)
+		write_fps.error |= (fsync(fileno(write_fps.cache_fp)) != 0);
+	if (prefs_common.flush_metadata && write_fps.mark_fp)
+		write_fps.error |= (fsync(fileno(write_fps.mark_fp)) != 0);
+	if (prefs_common.flush_metadata && write_fps.tags_fp)
+		write_fps.error |= (fsync(fileno(write_fps.tags_fp)) != 0);
 
-	fclose(write_fps.cache_fp);
-	fclose(write_fps.mark_fp);
-	fclose(write_fps.tags_fp);
+	/* close files */
+	if (write_fps.cache_fp)
+		write_fps.error |= (fclose(write_fps.cache_fp) != 0);
+	if (write_fps.mark_fp)
+		write_fps.error |= (fclose(write_fps.mark_fp) != 0);
+	if (write_fps.tags_fp)
+		write_fps.error |= (fclose(write_fps.tags_fp) != 0);
 
 
 	if (write_fps.error != 0) {
+		/* in case of error, forget all */
 		claws_unlink(new_cache);
 		claws_unlink(new_mark);
 		claws_unlink(new_tags);
@@ -1365,9 +1234,13 @@ gint msgcache_write(const gchar *cache_file, const gchar *mark_file, const gchar
 		g_free(new_tags);
 		return -1;
 	} else {
-		move_file(new_cache, cache_file, TRUE);
-		move_file(new_mark, mark_file, TRUE);
-		move_file(new_tags, tags_file, TRUE);
+		/* switch files */
+		if (cache_file)
+			move_file(new_cache, cache_file, TRUE);
+		if (mark_file)
+			move_file(new_mark, mark_file, TRUE);
+		if (tags_file)
+			move_file(new_tags, tags_file, TRUE);
 		cache->last_access = time(NULL);
 	}
 
