@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 the Claws Mail Team
+ * Copyright (C) 1999-2009 the Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -192,7 +192,7 @@ static void transport_sel_cb(GtkMenuItem *menuitem, gpointer data)
 	GtkTreeModel *model;
 	GtkTreeIter iter;
 	
-	g_return_if_fail(gtk_combo_box_get_active_iter(
+	cm_return_if_fail(gtk_combo_box_get_active_iter(
 			GTK_COMBO_BOX(page->transport_optmenu), &iter));
 	
 	model = gtk_combo_box_get_model(GTK_COMBO_BOX(page->transport_optmenu));			
