@@ -68,6 +68,7 @@ static GdkPixbuf *nomail_pixmap[2] = {NULL, NULL};
 static EggTrayIcon *trayicon;
 static GtkWidget *eventbox;
 static GtkWidget *image = NULL;
+static GtkWidget *focused_widget = NULL;
 
 #if !(GTK_CHECK_VERSION(2,12,0))
 static GtkTooltips *tooltips;
@@ -242,12 +243,14 @@ static gboolean trayicon_close_hook(gpointer source, gpointer data)
 		gboolean *close_allowed = (gboolean*)source;
 
 		if (trayicon_prefs.close_to_tray) {
-		MainWindow *mainwin = mainwindow_get_mainwindow();
+			MainWindow *mainwin = mainwindow_get_mainwindow();
 
 			*close_allowed = FALSE;
-		if (GTK_WIDGET_VISIBLE(GTK_WIDGET(mainwin->window)))
-			main_window_hide(mainwin);
-	}
+			focused_widget = gtk_window_get_focus(GTK_WINDOW(mainwin->window));
+			
+			if (gtkut_widget_get_visible(GTK_WIDGET(mainwin->window)))
+				main_window_hide(mainwin);
+		}
 	}
 	return FALSE;
 }
@@ -257,8 +260,9 @@ static gboolean trayicon_got_iconified_hook(gpointer source, gpointer data)
 	MainWindow *mainwin = mainwindow_get_mainwindow();
 
 	if (trayicon_prefs.hide_when_iconified
-			&& GTK_WIDGET_VISIBLE(GTK_WIDGET(mainwin->window))
+			&& gtkut_widget_get_visible(GTK_WIDGET(mainwin->window))
 			&& !gtk_window_get_skip_taskbar_hint(GTK_WINDOW(mainwin->window))) {
+		focused_widget = gtk_window_get_focus(GTK_WINDOW(mainwin->window));
 		gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), TRUE);
 	}
 	return FALSE;
@@ -295,14 +299,16 @@ static gboolean click_cb(GtkWidget * widget,
 
 	switch (event->button) {
 	case 1:
-		if (GTK_WIDGET_VISIBLE(GTK_WIDGET(mainwin->window))) {
+		if (gtkut_widget_get_visible(GTK_WIDGET(mainwin->window))) {
 			if ((gdk_window_get_state(GTK_WIDGET(mainwin->window)->window)&GDK_WINDOW_STATE_ICONIFIED)
 					|| mainwindow_is_obscured()) {
 				gtk_window_deiconify(GTK_WINDOW(mainwin->window));
 				gtk_window_set_skip_taskbar_hint(GTK_WINDOW(mainwin->window), FALSE);
 				main_window_show(mainwin);
 				gtk_window_present(GTK_WINDOW(mainwin->window));
+				gtk_window_set_focus(GTK_WINDOW(mainwin->window), focused_widget);
 			} else {
+				focused_widget = gtk_window_get_focus(GTK_WINDOW(mainwin->window));
 				main_window_hide(mainwin);
 			}
 		} else {
@@ -311,6 +317,7 @@ static gboolean click_cb(GtkWidget * widget,
 			main_window_show(mainwin);
 			gtk_window_present(GTK_WINDOW(mainwin->window));
 			fix_folderview_scroll(mainwin);
+			gtk_window_set_focus(GTK_WINDOW(mainwin->window), focused_widget);
         }
 		break;
 	case 3:
@@ -470,7 +477,7 @@ int plugin_init(gchar **error)
 	if (trayicon_prefs.hide_at_startup && claws_is_starting()) {
 		MainWindow *mainwin = mainwindow_get_mainwindow();
 
-		if (GTK_WIDGET_VISIBLE(GTK_WIDGET(mainwin->window)))
+		if (gtkut_widget_get_visible(GTK_WIDGET(mainwin->window)))
 			main_window_hide(mainwin);
 		main_set_show_at_startup(FALSE);
 	}
