@@ -142,6 +142,7 @@ void prefs_actions_open(MainWindow *mainwin)
 	prefs_actions_set_dialog();
 
 	gtk_widget_show(actions.window);
+	gtk_window_set_modal(GTK_WINDOW(actions.window), TRUE);
 }
 
 /*!
@@ -204,7 +205,6 @@ static void prefs_actions_create(MainWindow *mainwin)
 
 	gtk_container_set_border_width(GTK_CONTAINER (window), 8);
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
-	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	gtk_window_set_resizable(GTK_WINDOW(window), TRUE);
 
 	vbox = gtk_vbox_new(FALSE, 6);
@@ -349,11 +349,7 @@ static void prefs_actions_create(MainWindow *mainwin)
 	CLAWS_SET_TIP(clear_btn,
 			_("Clear all the input fields in the dialog"));
 
-#if GTK_CHECK_VERSION(2, 8, 0)
 	info_btn = gtk_button_new_from_stock(GTK_STOCK_INFO);
-#else
-	info_btn = gtk_button_new_with_label(_("Info..."));
-#endif
 	gtk_widget_show(info_btn);
 	gtk_box_pack_end(GTK_BOX(reg_hbox), info_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(info_btn), "clicked",
@@ -907,6 +903,7 @@ static void prefs_actions_cancel(GtkWidget *w, gpointer data)
 	gtk_list_store_clear(store);
 	prefs_actions_read_config();
 	gtk_widget_hide(actions.window);
+	gtk_window_set_modal(GTK_WINDOW(actions.window), FALSE);
 	inc_unlock();
 }
 
@@ -951,6 +948,7 @@ static void prefs_actions_ok(GtkWidget *widget, gpointer data)
 	}
 
 	gtk_widget_hide(actions.window);
+	gtk_window_set_modal(GTK_WINDOW(actions.window), FALSE);
 	inc_unlock();
 }
 
