@@ -818,8 +818,6 @@ static PrefParam param[] = {
 #ifndef G_OS_WIN32
 	{"uri_open_command", DEFAULT_BROWSER_CMD,
 	 &SPECIFIC_PREFS.uri_cmd, P_STRING, NULL, NULL, NULL},
-	{"print_command", "lpr %s",
-	 &SPECIFIC_PREFS.print_cmd, P_STRING, NULL, NULL, NULL},
 #endif
 	{"ext_editor_command", DEFAULT_EDITOR_CMD,
 	 &SPECIFIC_PREFS.ext_editor_cmd, P_STRING, NULL, NULL, NULL},
@@ -1035,6 +1033,11 @@ static PrefParam param[] = {
 	{"addrgather_height", "-1", &prefs_common.addrgather_height, P_INT,
 	 NULL, NULL, NULL},
 
+	{"news_subscribe_width", "450", &prefs_common.news_subscribe_width, P_INT,
+	 NULL, NULL, NULL},
+	{"news_subscribe_height", "400", &prefs_common.news_subscribe_height, P_INT,
+	 NULL, NULL, NULL},
+
 	/* Hidden */
 	{"warn_dnd", "1", &prefs_common.warn_dnd, P_INT,
 	 NULL, NULL, NULL},
