@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2007 Colin Leroy <colin@colino.net> & The Claws Mail Team
+ * Copyright (C) 2005-2009 Colin Leroy <colin@colino.net> & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,11 +60,11 @@ typedef struct _WritingPage
 	GtkWidget *checkbtn_default_reply_list;
 	GtkWidget *checkbtn_forward_as_attachment;
 	GtkWidget *checkbtn_redirect_keep_from;
-	GtkWidget *hbox_autosave;
 	GtkWidget *checkbtn_autosave;
 	GtkWidget *spinbtn_autosave_length;
+	GtkWidget *checkbtn_warn_large_insert;
+	GtkWidget *spinbtn_warn_large_insert_size;
 	GtkWidget *optmenu_dnd_insert_or_attach;
-	GtkWidget *entry_quote_chars;
 } WritingPage;
 
 static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *window, 
@@ -88,6 +88,12 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 	GtkObject *spinbtn_undolevel_adj;
 	GtkWidget *spinbtn_undolevel;
 
+	GtkWidget *hbox_warn_large_insert;
+	GtkWidget *checkbtn_warn_large_insert;
+	GtkObject *spinbtn_warn_large_insert_adj;
+	GtkWidget *spinbtn_warn_large_insert_size;
+	GtkWidget *label_warn_large_insert_size;
+
 	GtkWidget *checkbtn_reply_with_quote;
 	GtkWidget *checkbtn_default_reply_list;
 
@@ -106,13 +112,6 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 	GtkListStore *menu;
 	GtkTreeIter iter;
 
-	GtkWidget *frame_quote;
-	GtkWidget *hbox1;
-	GtkWidget *hbox2;
-	GtkWidget *vbox_quote;
-	GtkWidget *entry_quote_chars;
-	GtkWidget *label_quote_chars;
-
 	vbox1 = gtk_vbox_new (FALSE, VSPACING);
 	gtk_widget_show (vbox1);
 	gtk_container_set_border_width (GTK_CONTAINER (vbox1), VBOX_BORDER);
@@ -132,17 +131,20 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 	PACK_CHECK_BUTTON (hbox_autosel, checkbtn_reedit_account_autosel,
 			   _("when re-editing"));
 
+	/* Editing */
 	vbox2 = gtkut_get_options_frame(vbox1, &frame, _("Editing"));
 
+	/* Editing: automatically start the text editor */
 	PACK_CHECK_BUTTON (vbox2, checkbtn_autoextedit,
 			   _("Automatically launch the external editor"));
 
+	/* Editing: automatically save draft */
 	hbox_autosave = gtk_hbox_new (FALSE, 8);
 	gtk_widget_show (hbox_autosave);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_autosave, FALSE, FALSE, 0);
 
 	PACK_CHECK_BUTTON (hbox_autosave, checkbtn_autosave,
-			   _("Autosave message text to Drafts folder every"));
+			   _("Automatically save message to Drafts folder every"));
 
 	spinbtn_autosave_adj = gtk_adjustment_new (50, 0, 1000, 1, 10, 0);
 	spinbtn_autosave_length = gtk_spin_button_new
@@ -156,6 +158,7 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 	gtk_widget_show (label_autosave_length);
 	gtk_box_pack_start (GTK_BOX (hbox_autosave), label_autosave_length, FALSE, FALSE, 0);
 	
+	/* Editing: undo level */
 	hbox_undolevel = gtk_hbox_new (FALSE, 8);
 	gtk_widget_show (hbox_undolevel);
 	gtk_box_pack_start (GTK_BOX (vbox2), hbox_undolevel, FALSE, FALSE, 0);
@@ -171,7 +174,31 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 	gtk_box_pack_start (GTK_BOX (hbox_undolevel), spinbtn_undolevel, FALSE, FALSE, 0);
 	gtk_widget_set_size_request (spinbtn_undolevel, 64, -1);
 	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbtn_undolevel), TRUE);
-	
+
+	/* Editing: warn when inserting large files in message body */
+	hbox_warn_large_insert = gtk_hbox_new (FALSE, 8);
+	gtk_widget_show (hbox_warn_large_insert);
+	gtk_box_pack_start (GTK_BOX (vbox2), hbox_warn_large_insert, FALSE, FALSE, 0);
+
+	PACK_CHECK_BUTTON (hbox_warn_large_insert, checkbtn_warn_large_insert,
+			   _("Warn when inserting a file larger than"));
+
+	spinbtn_warn_large_insert_adj = gtk_adjustment_new (50, 0, 10000, 1, 10, 0);
+	spinbtn_warn_large_insert_size = gtk_spin_button_new
+		(GTK_ADJUSTMENT (spinbtn_warn_large_insert_adj), 1, 0);
+	gtk_widget_set_size_request (spinbtn_warn_large_insert_size, 64, -1);	
+	gtk_widget_show (spinbtn_warn_large_insert_size);
+	gtk_box_pack_start (GTK_BOX (hbox_warn_large_insert),
+			spinbtn_warn_large_insert_size, FALSE, FALSE, 0);
+	gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinbtn_warn_large_insert_size),
+			TRUE);
+
+ 	label_warn_large_insert_size = gtk_label_new(_("KB into message body "));
+	gtk_widget_show (label_warn_large_insert_size);
+	gtk_box_pack_start (GTK_BOX (hbox_warn_large_insert),
+			label_warn_large_insert_size, FALSE, FALSE, 0);
+
+	/* Replying */
 	vbox2 = gtkut_get_options_frame(vbox1, &frame, _("Replying"));
 
 	PACK_CHECK_BUTTON (vbox2, checkbtn_reply_with_quote,
@@ -213,32 +240,8 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 	SET_TOGGLE_SENSITIVITY (checkbtn_autosave, spinbtn_autosave_length);
 	SET_TOGGLE_SENSITIVITY (checkbtn_autosave, label_autosave_length);
 
-	/* quote chars */
-
-	PACK_FRAME (vbox1, frame_quote, _("Quotation characters"));
-
-	vbox_quote = gtk_vbox_new (FALSE, VSPACING_NARROW);
-	gtk_widget_show (vbox_quote);
-	gtk_container_add (GTK_CONTAINER (frame_quote), vbox_quote);
-	gtk_container_set_border_width (GTK_CONTAINER (vbox_quote), 8);
-
-	hbox1 = gtk_hbox_new (FALSE, 32);
-	gtk_widget_show (hbox1);
-	gtk_box_pack_start (GTK_BOX (vbox_quote), hbox1, FALSE, FALSE, 0);
-
-	hbox2 = gtk_hbox_new (FALSE, 8);
-	gtk_widget_show (hbox2);
-	gtk_box_pack_start (GTK_BOX (hbox1), hbox2, FALSE, FALSE, 0);
-
-	label_quote_chars = gtk_label_new (_("Treat these characters as quotation marks: "));
-	gtk_widget_show (label_quote_chars);
-	gtk_box_pack_start (GTK_BOX (hbox2), label_quote_chars, FALSE, FALSE, 0);
-
-	entry_quote_chars = gtk_entry_new ();
-	gtk_widget_show (entry_quote_chars);
-	gtk_box_pack_start (GTK_BOX (hbox2), entry_quote_chars,
-			    FALSE, FALSE, 0);
-	gtk_widget_set_size_request (entry_quote_chars, 64, -1);
+	SET_TOGGLE_SENSITIVITY (checkbtn_warn_large_insert, spinbtn_warn_large_insert_size);
+	SET_TOGGLE_SENSITIVITY (checkbtn_warn_large_insert, label_warn_large_insert_size);
 
 
 	prefs_writing->checkbtn_autoextedit = checkbtn_autoextedit;
@@ -251,6 +254,9 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 
 	prefs_writing->checkbtn_autosave     = checkbtn_autosave;
 	prefs_writing->spinbtn_autosave_length = spinbtn_autosave_length;
+
+	prefs_writing->checkbtn_warn_large_insert = checkbtn_warn_large_insert;
+	prefs_writing->spinbtn_warn_large_insert_size = spinbtn_warn_large_insert_size;
 	
 	prefs_writing->checkbtn_forward_as_attachment =
 		checkbtn_forward_as_attachment;
@@ -260,7 +266,6 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 
 	prefs_writing->optmenu_dnd_insert_or_attach = optmenu_dnd_insert_or_attach;
 
-	prefs_writing->entry_quote_chars	= entry_quote_chars;
 
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_writing->checkbtn_autoextedit),
 		prefs_common.auto_exteditor);
@@ -274,6 +279,10 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 		prefs_common.autosave_length);
 	gtk_spin_button_set_value(GTK_SPIN_BUTTON(prefs_writing->spinbtn_undolevel),
 		prefs_common.undolevels);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_writing->checkbtn_warn_large_insert),
+		prefs_common.warn_large_insert);
+	gtk_spin_button_set_value(GTK_SPIN_BUTTON(prefs_writing->spinbtn_warn_large_insert_size),
+		prefs_common.warn_large_insert_size);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_writing->checkbtn_reply_account_autosel),
 		prefs_common.reply_account_autosel);
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(prefs_writing->checkbtn_forward_account_autosel),
@@ -286,8 +295,6 @@ static void prefs_compose_writing_create_widget(PrefsPage *_page, GtkWindow *win
 		prefs_common.default_reply_list);
 	combobox_select_by_data(GTK_COMBO_BOX(optmenu_dnd_insert_or_attach),
 		prefs_common.compose_dnd_mode);
-	gtk_entry_set_text(GTK_ENTRY(entry_quote_chars), 
-			prefs_common.quote_chars?prefs_common.quote_chars:"");
 
 	prefs_writing->page.widget = vbox1;
 }
@@ -308,6 +315,10 @@ static void prefs_compose_writing_save(PrefsPage *_page)
 		gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(page->spinbtn_autosave_length));
 	prefs_common.undolevels = 
 		gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(page->spinbtn_undolevel));
+	prefs_common.warn_large_insert = 
+		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->checkbtn_warn_large_insert));
+	prefs_common.warn_large_insert_size =
+		gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON(page->spinbtn_warn_large_insert_size));
 		
 	prefs_common.reply_account_autosel =
 		gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(page->checkbtn_reply_account_autosel));
@@ -322,11 +333,6 @@ static void prefs_compose_writing_save(PrefsPage *_page)
 	
 	prefs_common.compose_dnd_mode = combobox_get_active_data(
 			GTK_COMBO_BOX(page->optmenu_dnd_insert_or_attach));
-
-	g_free(prefs_common.quote_chars); 
-	prefs_common.quote_chars = gtk_editable_get_chars(
-			GTK_EDITABLE(page->entry_quote_chars), 0, -1);
-	remove_space(prefs_common.quote_chars);
 }
 
 static void prefs_compose_writing_destroy_widget(PrefsPage *_page)
