@@ -125,6 +125,7 @@ void prefs_custom_header_open(PrefsAccount *ac)
 	cur_ac = ac;
 
 	gtk_widget_show(customhdr.window);
+	gtk_window_set_modal(GTK_WINDOW(customhdr.window), TRUE);
 }
 
 static void prefs_custom_header_create(void)
@@ -166,7 +167,6 @@ static void prefs_custom_header_create(void)
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "prefs_customheader");
 	gtk_container_set_border_width (GTK_CONTAINER (window), 8);
 	gtk_window_set_position (GTK_WINDOW (window), GTK_WIN_POS_CENTER);
-	gtk_window_set_modal (GTK_WINDOW (window), TRUE);
 	gtk_window_set_resizable(GTK_WINDOW (window), TRUE);
 
 	vbox = gtk_vbox_new (FALSE, 6);
@@ -233,7 +233,7 @@ static void prefs_custom_header_create(void)
 			  0, 0, 0);
 	gtk_widget_set_size_request (val_entry, 200, -1);
 
-	val_btn = gtk_button_new_with_label (_("From file..."));
+	val_btn = gtkut_get_browse_file_btn(_("Bro_wse"));
 	gtk_widget_show (val_btn);
 	gtk_table_attach (GTK_TABLE (table1), val_btn, 2, 3, 1, 2,
 			  GTK_EXPAND | GTK_SHRINK | GTK_FILL,
@@ -787,12 +787,14 @@ static void prefs_custom_header_ok(void)
 {
 	prefs_custom_header_write_config(cur_ac);
 	gtk_widget_hide(customhdr.window);
+	gtk_window_set_modal(GTK_WINDOW(customhdr.window), FALSE);
 }
 
 static void prefs_custom_header_cancel(void)
 {
 	prefs_custom_header_read_config(cur_ac); 
 	gtk_widget_hide(customhdr.window);
+	gtk_window_set_modal(GTK_WINDOW(customhdr.window), FALSE);
 }
 
 static gint prefs_custom_header_deleted(GtkWidget *widget, GdkEventAny *event,
@@ -910,7 +912,7 @@ static gboolean prefs_custom_header_selected(GtkTreeSelection *selector,
 
 	ENTRY_SET_TEXT(customhdr.hdr_entry, ch->name);
 	ENTRY_SET_TEXT(customhdr.val_entry, ch->value);
-	if (!g_strcmp0("Face",ch->name)) {
+	if (!strcmp2("Face",ch->name)) {
 		preview = GTK_IMAGE(face_get_from_header (ch->value));
 		pixbuf = gtk_image_get_pixbuf(preview);
 		gtk_image_set_from_pixbuf (GTK_IMAGE(customhdr.preview), pixbuf);
@@ -923,7 +925,7 @@ static gboolean prefs_custom_header_selected(GtkTreeSelection *selector,
 #endif
 	} 
 #if HAVE_LIBCOMPFACE
-else if (!g_strcmp0("X-Face", ch->name)) {
+else if (!strcmp2("X-Face", ch->name)) {
 		GdkColor color;
 		color.pixel = 0;
 		preview = GTK_IMAGE(xface_get_from_header(ch->value, 
