@@ -359,6 +359,7 @@ static void prefs_matcher_models_create(void)
 	COMBOBOX_ADD(store, "X-Mailer", CRITERIA_HEADER);
 	COMBOBOX_ADD(store, "X-BeenThere", CRITERIA_HEADER);
 	COMBOBOX_ADD(store, "List-Post", CRITERIA_HEADER);
+	COMBOBOX_ADD(store, "List-Id", CRITERIA_HEADER);
 	matcher.model_headers = GTK_TREE_MODEL(store);
 	
 	store = gtk_list_store_new(3, G_TYPE_STRING, G_TYPE_INT, G_TYPE_BOOLEAN);
@@ -711,11 +712,7 @@ static void prefs_matcher_create(void)
 			 GTK_FILL, GTK_SHRINK, 4, 0);
 
 	/* test info button */
-#if GTK_CHECK_VERSION(2, 8, 0)
 	test_btn = gtk_button_new_from_stock(GTK_STOCK_INFO);
-#else
-	test_btn = gtk_button_new_with_label(_("Info..."));
-#endif
 	gtk_box_pack_start(GTK_BOX(lower_hbox), test_btn, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT (test_btn), "clicked",
 			 G_CALLBACK(prefs_matcher_test_info),
