@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2005-2007 Colin Leroy <colin@colino.net> & The Claws Mail Team
+ * Copyright (C) 2005-2009 Colin Leroy <colin@colino.net> & The Claws Mail Team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -62,7 +62,7 @@ QuotePage *prefs_quote;
 
 static void prefs_quote_set_default_new_msg_fmt(void)
 {
-	g_return_if_fail(prefs_quote->text_format != NULL);
+	cm_return_if_fail(prefs_quote->text_format != NULL);
 
 	pref_set_textview_from_pref(GTK_TEXT_VIEW(prefs_quote->text_format),
 		_("Hello,\\n"));
@@ -70,7 +70,7 @@ static void prefs_quote_set_default_new_msg_fmt(void)
 
 static void prefs_quote_set_default_reply_fmt(void)
 {
-	g_return_if_fail(prefs_quote->text_quotefmt != NULL);
+	cm_return_if_fail(prefs_quote->text_quotefmt != NULL);
 
 	pref_set_textview_from_pref(GTK_TEXT_VIEW(prefs_quote->text_quotefmt),
 		_("On %d\\n%f wrote:\\n\\n%q"));
@@ -78,7 +78,7 @@ static void prefs_quote_set_default_reply_fmt(void)
 
 static void prefs_quote_set_default_forward_fmt(void)
 {
-	g_return_if_fail(prefs_quote->text_fw_quotefmt != NULL);
+	cm_return_if_fail(prefs_quote->text_fw_quotefmt != NULL);
 
 	pref_set_textview_from_pref(GTK_TEXT_VIEW(prefs_quote->text_fw_quotefmt),
 		_("\\n\\nBegin forwarded message:\\n\\n"
