@@ -528,11 +528,7 @@ static void prefs_summaries_create_widget(PrefsPage *_page, GtkWindow *window,
 	gtk_widget_set_size_request(entry_datefmt, 200, -1);
 	gtk_box_pack_start (GTK_BOX (hbox2), entry_datefmt, FALSE, FALSE, 0);
 
-#if GTK_CHECK_VERSION(2, 8, 0)
 	button_datefmt = gtk_button_new_from_stock(GTK_STOCK_INFO);
-#else
-	button_datefmt = gtk_button_new_with_label ("Info...");
-#endif
 
 	gtk_widget_show (button_datefmt);
 	gtk_box_pack_start (GTK_BOX (hbox2), button_datefmt, FALSE, FALSE, 0);
