@@ -176,13 +176,14 @@ void prefs_summary_column_open(void)
 	prefs_summary_column_set_dialog(NULL);
 
 	gtk_widget_show(summary_col.window);
+	gtk_window_set_modal(GTK_WINDOW(summary_col.window), TRUE);
 
 	summary_col.finished = FALSE;
 	while (summary_col.finished == FALSE)
 		gtk_main_iteration();
 
 	gtk_widget_hide(summary_col.window);
-
+	gtk_window_set_modal(GTK_WINDOW(summary_col.window), FALSE);
 	inc_unlock();
 }
 
@@ -219,7 +220,6 @@ static void prefs_summary_column_create(void)
 	window = gtkut_window_new(GTK_WINDOW_TOPLEVEL, "prefs_summary_column");
 	gtk_container_set_border_width(GTK_CONTAINER(window), 8);
 	gtk_window_set_position(GTK_WINDOW(window), GTK_WIN_POS_CENTER);
-	gtk_window_set_modal(GTK_WINDOW(window), TRUE);
 	gtk_window_set_resizable(GTK_WINDOW(window), FALSE);
 	gtk_window_set_title(GTK_WINDOW(window),
 			     _("Message list columns configuration"));
