@@ -164,7 +164,7 @@ void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 		gtk_widget_show (hbox2_format);
 		gtk_box_pack_start (GTK_BOX (vbox_format), hbox2_format, FALSE, FALSE, 0);
 
-		label_from = gtk_label_new (_("From"));
+		label_from = gtk_label_new (prefs_common_translated_header_name("From"));
 		gtk_misc_set_alignment(GTK_MISC(label_from), 1, 0.5);
 		gtk_widget_show (label_from);
 		gtk_box_pack_start (GTK_BOX (hbox2_format), label_from, FALSE, FALSE, 0);
@@ -183,7 +183,7 @@ void quotefmt_create_new_msg_fmt_widgets(GtkWindow *parent_window,
 	gtk_widget_show (hbox_format);
 	gtk_box_pack_start (GTK_BOX (vbox_format), hbox_format, FALSE, FALSE, 0);
 
-	label_subject = gtk_label_new (_("Subject"));
+	label_subject = gtk_label_new (prefs_common_translated_header_name("Subject"));
 	gtk_misc_set_alignment(GTK_MISC(label_subject), 1, 0.5);
 	gtk_widget_show (label_subject);
 	gtk_box_pack_start (GTK_BOX (hbox_format), label_subject, FALSE, FALSE, 0);
@@ -292,7 +292,7 @@ void quotefmt_create_reply_fmt_widgets(GtkWindow *parent_window,
 		gtk_widget_show (hbox3);
 		gtk_box_pack_start (GTK_BOX (vbox_quote), hbox3, FALSE, FALSE, 0);
 
-		label_from = gtk_label_new (_("From"));
+		label_from = gtk_label_new (prefs_common_translated_header_name("From"));
 		gtk_misc_set_alignment(GTK_MISC(label_from), 1, 0.5);
 		gtk_widget_show (label_from);
 		gtk_box_pack_start (GTK_BOX (hbox3), label_from, FALSE, FALSE, 0);
@@ -424,7 +424,7 @@ void quotefmt_create_forward_fmt_widgets(GtkWindow *parent_window,
 		gtk_widget_show (hbox3);
 		gtk_box_pack_start (GTK_BOX (vbox_quote), hbox3, FALSE, FALSE, 0);
 
-		label_from = gtk_label_new (_("From"));
+		label_from = gtk_label_new (prefs_common_translated_header_name("From"));
 		gtk_misc_set_alignment(GTK_MISC(label_from), 1, 0.5);
 		gtk_widget_show (label_from);
 		gtk_box_pack_start (GTK_BOX (hbox3), label_from, FALSE, FALSE, 0);
@@ -519,12 +519,7 @@ void quotefmt_add_info_button(GtkWindow *parent_window, GtkWidget *parent_box)
 	gtk_box_pack_start (GTK_BOX (parent_box), hbox_formatdesc, FALSE, FALSE,
 				VBOX_BORDER);
 
-#if GTK_CHECK_VERSION(2, 8, 0)
 	btn_formatdesc = gtk_button_new_from_stock(GTK_STOCK_INFO);
-#else
-	btn_formatdesc =
-		gtk_button_new_with_label (_("Description of symbols..."));
-#endif
 	gtk_widget_show (btn_formatdesc);
 	gtk_box_pack_start (GTK_BOX (hbox_formatdesc), btn_formatdesc, FALSE, FALSE, 0);
 	g_signal_connect(G_OBJECT(btn_formatdesc), "clicked",
