@@ -1,6 +1,6 @@
 /*
  * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2007 Colin Leroy <colin@colino.net> 
+ * Copyright (C) 1999-2009 Colin Leroy <colin@colino.net> 
  * and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
@@ -317,7 +317,8 @@ static gchar *wizard_get_default_domain_name(void)
 	
 	if (domain_name == NULL) {
 		domain_name = g_strdup(get_domain_name());
-		if (strchr(domain_name, '.') != strrchr(domain_name, '.')
+		if (strchr(domain_name, '.') != NULL 
+		&& strchr(domain_name, '.') != strrchr(domain_name, '.')
 		&& strlen(strchr(domain_name, '.')) > 6) {
 			gchar *tmp = g_strdup(strchr(domain_name, '.')+1);
 			g_free(domain_name);
@@ -1774,6 +1775,7 @@ gboolean run_wizard(MainWindow *mainwin, gboolean create_mailbox) {
 			GTK_STOCK_CANCEL, CANCEL,
 			NULL);
 	gtk_widget_set_size_request(wizard->window, -1, 480);
+	gtk_window_set_position(GTK_WINDOW(wizard->window), GTK_WIN_POS_CENTER);
 
 	g_signal_connect(wizard->window, "response", 
 			  G_CALLBACK(wizard_response_cb), wizard);
